import type { OpenId4VciAuthCodeFlowOptions, OpenId4VciAcceptCredentialOfferOptions, OpenId4VciResolvedCredentialOffer, OpenId4VciResolvedAuthorizationRequest, OpenId4VciResolvedAuthorizationRequestWithCode } from './OpenId4VciHolderServiceOptions';
import type { AgentContext, VerifiableCredential } from '@credo-ts/core';
import { JwsService, Logger, W3cCredentialService } from '@credo-ts/core';
export declare class OpenId4VciHolderService {
    private logger;
    private w3cCredentialService;
    private jwsService;
    constructor(logger: Logger, w3cCredentialService: W3cCredentialService, jwsService: JwsService);
    resolveCredentialOffer(credentialOffer: string): Promise<OpenId4VciResolvedCredentialOffer>;
    private getAuthDetailsFromOfferedCredential;
    resolveAuthorizationRequest(agentContext: AgentContext, resolvedCredentialOffer: OpenId4VciResolvedCredentialOffer, authCodeFlowOptions: OpenId4VciAuthCodeFlowOptions): Promise<OpenId4VciResolvedAuthorizationRequest>;
    acceptCredentialOffer(agentContext: AgentContext, options: {
        resolvedCredentialOffer: OpenId4VciResolvedCredentialOffer;
        acceptCredentialOfferOptions: OpenId4VciAcceptCredentialOfferOptions;
        resolvedAuthorizationRequestWithCode?: OpenId4VciResolvedAuthorizationRequestWithCode;
    }): Promise<VerifiableCredential[]>;
    /**
     * Get the options for the credential request. Internally this will resolve the proof of possession
     * requirements, and based on that it will call the proofOfPossessionVerificationMethodResolver to
     * allow the caller to select the correct verification method based on the requirements for the proof
     * of possession.
     */
    private getCredentialRequestOptions;
    /**
     * Get the requirements for creating the proof of possession. Based on the allowed
     * credential formats, the allowed proof of possession signature algorithms, and the
     * credential type, this method will select the best credential format and signature
     * algorithm to use, based on the order of preference.
     */
    private getProofOfPossessionRequirements;
    private handleCredentialResponse;
    private proofOfPossessionSignCallback;
}
